@@ -1,19 +1,28 @@
 from importlib import import_module
 
 from ddtrace import config
+from ddtrace.contrib.trace_utils import ext_service
 from ddtrace.vendor.wrapt import wrap_function_wrapper as _w
 
-from ...compat import urlencode
 from ...constants import ANALYTICS_SAMPLE_RATE_KEY
 from ...constants import SPAN_MEASURED_KEY
 from ...ext import SpanTypes
 from ...ext import elasticsearch as metadata
 from ...ext import http
+from ...internal.compat import urlencode
+from ...internal.utils.wrappers import unwrap as _u
 from ...pin import Pin
-from ...utils.wrappers import unwrap as _u
 from .quantize import quantize
 
 
+config._add(
+    "elasticsearch",
+    {
+        "_default_service": "elasticsearch",
+    },
+)
+
+
 def _es_modules():
     module_names = (
         "elasticsearch",
@@ -41,7 +50,7 @@ def _patch(elasticsearch):
         return
     setattr(elasticsearch, "_datadog_patch", True)
     _w(elasticsearch.transport, "Transport.perform_request", _get_perform_request(elasticsearch))
-    Pin(service=metadata.SERVICE, app=metadata.APP).onto(elasticsearch.transport.Transport)
+    Pin().onto(elasticsearch.transport.Transport)
 
 
 def unpatch():
@@ -61,7 +70,9 @@ def _get_perform_request(elasticsearch):
         if not pin or not pin.enabled():
             return func(*args, **kwargs)
 
-        with pin.tracer.trace("elasticsearch.query", span_type=SpanTypes.ELASTICSEARCH) as span:
+        with pin.tracer.trace(
+            "elasticsearch.query", service=ext_service(pin, config.elasticsearch), span_type=SpanTypes.ELASTICSEARCH
+        ) as span:
             span.set_tag(SPAN_MEASURED_KEY)
 
             # Don't instrument if the trace is not sampled
@@ -73,7 +84,6 @@ def _get_perform_request(elasticsearch):
             encoded_params = urlencode(params)
             body = kwargs.get("body")
 
-            span.service = pin.service
             span.set_tag(metadata.METHOD, method)
             span.set_tag(metadata.URL, url)
             span.set_tag(metadata.PARAMS, encoded_params)
