@@ -1,13 +1,14 @@
 import grpc
 
 from ddtrace import config
-from ddtrace.compat import to_unicode
-from ddtrace.ext import errors
+from ddtrace.internal.compat import to_unicode
 from ddtrace.vendor import wrapt
 
 from . import constants
 from .. import trace_utils
 from ...constants import ANALYTICS_SAMPLE_RATE_KEY
+from ...constants import ERROR_MSG
+from ...constants import ERROR_TYPE
 from ...constants import SPAN_MEASURED_KEY
 from ...ext import SpanTypes
 from .utils import set_grpc_method_meta
@@ -37,8 +38,8 @@ def _handle_server_exception(server_context, span):
         code = to_unicode(server_context._state.code)
         details = to_unicode(server_context._state.details)
         span.error = 1
-        span._set_str_tag(errors.ERROR_MSG, details)
-        span._set_str_tag(errors.ERROR_TYPE, code)
+        span._set_str_tag(ERROR_MSG, details)
+        span._set_str_tag(ERROR_TYPE, code)
 
 
 def _wrap_response_iterator(response_iterator, server_context, span):
